# ForwarderDetailedStats

Detailed statistics about a forwarder 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bind_stats** | [**[AgentConnectorLocalBindStats]**](AgentConnectorLocalBindStats.md) | The stats for the local binds of this forwarder. Note that if the forwarder is listening on too many ports, this list may be truncated.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


